==> haskell-libmpd-0.9.0.8-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-4gsKkztqV5TAM2AuCraJ7D
key: libmpd-0.9.0.8-4gsKkztqV5TAM2AuCraJ7D
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 61de20c548b9711bdc7064390a3091fc
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-4gsKkztqV5TAM2AuCraJ7D
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 filepath-1.4.2.1
    mtl-2.2.2 network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libmpd-0.9.0.8-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-73Rqfpu4UUgIf5Sn8oJjHh
key: libmpd-0.9.0.8-73Rqfpu4UUgIf5Sn8oJjHh
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 2997f42837177a0ce613f6fad7614e5c
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.6.5/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-73Rqfpu4UUgIf5Sn8oJjHh
depends:
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 filepath-1.4.2.1
    mtl-2.2.2 network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
